// A constant representing the combined model/view/projection matrix.
uniform mat4 u_MVPMatrix;
uniform mat4 u_TexMatrix;
uniform float u_Alpha;
// here's a brightness value that we pass in
uniform float u_Brightness;
       
// Per-vertex position information we will pass in.
attribute vec4 a_Position;
// Per-vertex color information we will pass in.
attribute vec4 a_Color;
// tex coordinate that we will pass in
attribute vec2 a_TexCoordinate0;
// tex coordinate reference from 0 to 1
attribute vec2 a_TexCoordinateRef;

// tex coordinate to pass to the pixel shader
varying vec2 v_TexCoordinate0;
// this is the reference tex coordinate from 0 to 1
varying vec2 v_TexCoordinateRef;
// This will be passed into the fragment shader.
varying vec4 v_Color;           
// The entry point for our vertex shader.
void main()
{                          
    // Pass the color through to the fragment shader.
    // It will be interpolated across the triangle.
    v_Color.rgb = a_Color.rgb * u_Brightness;
    
    // now, can set a alpha color for transparency
    v_Color.a = u_Alpha;
    
    // transform our tex coordinates here
    vec4 texCoordinate = vec4(a_TexCoordinate0.x, a_TexCoordinate0.y, 0.0, 1.0);
    vec4 texTransformed = u_TexMatrix * texCoordinate;
    v_TexCoordinate0 = texTransformed.xy;
    v_TexCoordinateRef = a_TexCoordinateRef;
    
    // gl_Position is a special variable used to store the final position.
    // Multiply the vertex by the matrix to get the final point in
    gl_Position = u_MVPMatrix * a_Position;
}         