/*
 * Readable code before optimization
 */

/*

// Set the default precision to medium. We don't need as high of a
// precision in the fragment shader.
precision mediump float;

// the input texture
uniform sampler2D u_Texture;
uniform sampler2D u_Texture1;

uniform vec2 u_ImageTexCoordBorderTopRight;
uniform vec2 u_ImageTexCoordBorderBottomLeft;

// This is the color from the vertex shader interpolated across the
// triangle per fragment.
varying vec4 v_Color;
// the interpolated texture coord per fragment
varying vec2 v_TexCoordinate0;

varying vec2 v_TexCoordTopLeft;
varying vec2 v_TexCoordTopRight;
varying vec2 v_TexCoordBottomLeft;
varying vec2 v_TexCoordBottomRight;

const vec2 center = vec2(0.5, 0.5);

// The entry point for our fragment shader.
void main()
{
    //Some performance tips for shaders:
    // 1. Avoid branching, as this will corrupt the shader pipeline. This is because the fragment shaders are executed parallel and they must execute the same instructions. Dynamic branching is not supported and the pipeline will stall or flush.
    // 2. Avoid dependent texture reads. This is because the texture coordinate depends on the execution result of some code in the shader. this texture reads can't be pre-fetched and optimized by the GPU.
    // In PowerVR 5x GPU, dependent texture reads has a huge performance impact so we sample all the fragments with varying in order to let pre-fetch texture happens before the fragment shader. This could improve the performance a lot.
    // However, in Adreno 330, as it is OpenGL ES3.0 capable, we don't have a performance penalty using dependent texture reads.
    // In order to keep the consistency of the code, we use the same algorithm here.

    vec4 pictureColor = texture2D(u_Texture, v_TexCoordinate0);
    vec4 shadowTopLeft = texture2D(u_Texture1, v_TexCoordTopLeft);
    vec4 shadowTopRight = texture2D(u_Texture1, v_TexCoordTopRight);
    vec4 shadowBottomLeft = texture2D(u_Texture1, v_TexCoordBottomLeft);
    vec4 shadowBottomRight = texture2D(u_Texture1, v_TexCoordBottomRight);
    // we'll ignore the sampled alpha channel and just use 1.0
    pictureColor.a = 1.0;

    //when hitTest is vec2(0, 0), it is a picture, otherwise it is shadow
    vec2 hitTest = step(v_TexCoordinate0, u_ImageTexCoordBorderBottomLeft) + step(u_ImageTexCoordBorderTopRight, v_TexCoordinate0);
    float isShadow = clamp(hitTest.x + hitTest.y, 0.0, 1.0);

    // Hit test:
    // bottomLeft: vec2(0, 0)
    // bottomRight: vec2(1, 0)
    // topLeft: vec2(0, 1)
    // topRight: vec2(1, 1)
    vec2 regionHitTest = step(center, v_TexCoordinate0);
    vec4 shadowColor = mix( mix(shadowBottomLeft, shadowTopLeft, regionHitTest.y), mix(shadowBottomRight, shadowTopRight, regionHitTest.y), regionHitTest.x);

    gl_FragColor = mix(v_Color * pictureColor, shadowColor, isShadow);
}

*/


/*
 * Unreadable code optimized by PowerVR Shader Editor 2.3
 */
precision mediump float;
varying vec2 v_TexCoordBottomRight;
varying vec2 v_TexCoordBottomLeft;
varying vec2 v_TexCoordTopRight;
varying vec2 v_TexCoordTopLeft;
varying vec2 v_TexCoordinate0;
varying vec4 v_Color;
uniform vec2 u_ImageTexCoordBorderBottomLeft;
uniform vec2 u_ImageTexCoordBorderTopRight;
uniform sampler2D u_Texture1;
uniform sampler2D u_Texture;
void main ()
{
  lowp vec4 pictureColor_1;
  pictureColor_1.xyz = texture2D (u_Texture, v_TexCoordinate0).xyz;
  pictureColor_1.w = 1.0;
  vec2 t_2;
  t_2.x = float((u_ImageTexCoordBorderBottomLeft.x >= v_TexCoordinate0.x));
  t_2.y = float((u_ImageTexCoordBorderBottomLeft.y >= v_TexCoordinate0.y));
  vec2 t_3;
  t_3.x = float((v_TexCoordinate0.x >= u_ImageTexCoordBorderTopRight.x));
  t_3.y = float((v_TexCoordinate0.y >= u_ImageTexCoordBorderTopRight.y));
  vec2 tmpvar_4;
  tmpvar_4 = (t_2 + t_3);
  vec2 t_5;
  t_5.x = float((v_TexCoordinate0.x >= 0.5));
  t_5.y = float((v_TexCoordinate0.y >= 0.5));
  lowp vec4 tmpvar_6;
  tmpvar_6 = mix ((v_Color * pictureColor_1), mix (mix (texture2D (u_Texture1, v_TexCoordBottomLeft), texture2D (u_Texture1, v_TexCoordTopLeft), t_5.y), mix (texture2D (u_Texture1, v_TexCoordBottomRight), texture2D (u_Texture1, v_TexCoordTopRight), t_5.y), t_5.x), clamp ((tmpvar_4.x + tmpvar_4.y), 0.0, 1.0));
  gl_FragColor = tmpvar_6;
}

