#extension GL_OES_EGL_image_external : require

// Set the default precision to medium. We don't need as high of a
// precision in the fragment shader.
precision mediump float; 

// the input texture
uniform samplerExternalOES u_Texture;
// here's a brightness value that we pass in
uniform float u_Brightness;
uniform mediump mat3 u_ConvKernel;

// This is the color from the vertex shader interpolated across the
// triangle per fragment.
varying vec4 v_Color;
// the interpolated texture coord per fragment
varying vec2 v_TexCoordinate0;
varying vec2 v_TexCoordinateRef;
// The entry point for our fragment shader.

// here are out coordinates which have been interpolated
// by the hardware of our neighbouring fragments.
varying vec2 v_TopLeft;
varying vec2 v_TopRight;
varying vec2 v_BotLeft;
varying vec2 v_BotRight;

// weight to average out the colors
const float WEIGHT = 0.25;

void main()
{
    // sample the colors of our neighbouring fragments in a 3x3 convolution matrix
    mediump vec4 topLeftColor = texture2D(u_Texture, v_TopLeft);
    mediump vec4 topRightColor = texture2D(u_Texture, v_TopRight);
    mediump vec4 botLeftColor = texture2D(u_Texture, v_BotLeft);
    mediump vec4 botRightColor = texture2D(u_Texture, v_BotRight);
    //mediump vec4 centerColor = texture2D(u_Texture, v_TexCoordinate0);

    // get the threshold value that's placed in the alpha channel
    float threshold = topLeftColor.a;

    mediump vec4 blurredColor;
    // now, accumulate the color of our current fragment, as a sum of all our neighbouring
    // fragments, taking into account the factors in our convulation matrix
    blurredColor = (WEIGHT * topLeftColor) + (WEIGHT * topRightColor) + (WEIGHT * botLeftColor) + (WEIGHT * botRightColor);

    // we blend original texel color with blurredColor - higher threshold, more blurredColor
    vec4 blendedColor = mix(topLeftColor, blurredColor, threshold);

    // make the final composited texel color alpha full
    blendedColor.a = 1.0;

    // now multiple with the texture color
    gl_FragColor = u_Brightness * (v_Color * blendedColor);
}