// Set the default precision to medium. We don't need as high of a
// precision in the fragment shader.
precision mediump float;

// the antialias threshold, such as 0.01 which is related to texture coordinates
uniform float u_AntialiasThreshold;

// This is the color from the vertex shader interpolated across the
// triangle per fragment.
varying vec4 v_Color;
// the interpolated texture coord per fragment
varying vec2 v_TexCoordinate0;


//inline keyword is reserved in the spec but not used so we can't use inline here
float calculateAlpha(float x, float y) {
    return 1.0 - clamp((x - y) / u_AntialiasThreshold, 0.0, 1.0);
}

void main()
{
    //Algorithm see https://issues.labcollab.net/browse/PHOTOS-3283
    gl_FragColor = v_Color;
    if (v_TexCoordinate0.x > 0.5) {
        gl_FragColor.a = 0.0;
    } else if (v_TexCoordinate0.x > v_TexCoordinate0.y) {
        gl_FragColor.a = calculateAlpha(v_TexCoordinate0.x, v_TexCoordinate0.y) * v_Color.a;
    } else if (v_TexCoordinate0.x > 1.0 - v_TexCoordinate0.y) {
        gl_FragColor.a = calculateAlpha(v_TexCoordinate0.x, 1.0 - v_TexCoordinate0.y) * v_Color.a;
    }
}